##  SUBSCRIPTION_CREATED

```
{
  "id": 42854,
  "type": "SubscriptionCreatedEvent",
  "fsType": "Application",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "createdAt": "2024-02-16T13:20:23.769518Z",
  "roleInfos": [],
  "fsIdAndRev": {
    "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
    "rev": 6
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "subscriptionId": "39aae878-6ded-40de-aa01-9524ce3ee6d0",
  "subscribedUserId": "8393b7a8-8bfb-4989-a348-6cb31d56745f",
  "subscriptionType": "RESPONSIBLE",
  "transactionSequenceNumber": 75091
}
```



